<?php

include __DIR__."/builtin_extensions.inc";

class A_DOMEntityReference extends DOMEntityReference {
  public $___x;
}
test("DOMEntityReference", "Foo");
